import React, { HTMLAttributes } from 'react';
declare type ButtonWidth = 'fit-content' | '100%' | string;
declare type ButtonSize = 'small' | 'medium' | 'large';
declare type ButtonColor = 'gray' | 'red' | 'blue';
declare type ButtonVariant = 'default' | 'contained' | 'outlined' | 'text';
export interface ButtonProps extends HTMLAttributes<'button'> {
    /**
     * 버튼 내부에 표시되는 컴포넌트입니다.
     */
    children?: React.ReactNode;
    /**
     * 버튼의 전체적인 스타일입니다.
     */
    variant?: ButtonVariant;
    color?: ButtonColor;
    disabled?: boolean;
    size?: ButtonSize;
    /**
     * 버튼의 border-radius 속성입니다.
     */
    borderRadius?: number;
    /**
     * isLoading일 경우 label 대신 \<Spinner\>가 표시됩니다. width와 같이 사용하는 것을 추천합니다.
     */
    isLoading?: boolean;
    /**
     * label 왼쪽에 표시되는 아이콘입니다.
     *
     * (!children && icon && !width) 인 경우 가로 세로 크기가 똑같은 iconOnly 버튼이 됩니다.
     */
    icon?: React.ReactNode | string;
    /**
     * icon이 버튼에서 표시될 위치를 정합니다.
     */
    iconPosition?: 'start' | 'end';
    onClick?: () => void;
    type?: 'submit' | 'button';
    /**
     * 버튼의 너비를 지정할 수 있습니다.
     */
    width?: ButtonWidth;
    /**
     * string 또는 컴포넌트를 입력하여 태그처럼 사용할 수 있습니다.
     * styled-components의 as prop을 참고하세요.
     *
     * ex. "a", Link(react-router-dom)
     */
    as?: any;
    /**
     * as를 사용했을 때 컴포넌트에 전달할 추가적인 props입니다.
     *
     * ex. { href: "/" }
     */
    asProps?: {
        [key: string]: any;
    };
}
/**
 * 버튼
 */
export declare const Button: React.ForwardRefExoticComponent<ButtonProps & React.RefAttributes<HTMLButtonElement>>;
export {};
