import React from 'react';
import { TextFieldProps } from '.';
declare type AutocompleteItem = {
    text: string;
    id: number;
};
export declare type AutocompleteProps = TextFieldProps & {
    /**
     * 자동 완성 항목입니다.
     */
    items: AutocompleteItem[];
    type?: 'text' | 'password' | 'search' | 'url' | 'email';
};
/**
 * 자동 완성을 지원하는 \<TextField\>입니다.
 * 현재 영어만 사용할 수 있습니다. IME를 사용하는 언어(한국어 등)은 정상적으로 작동하지 않습니다.
 */
export declare const Autocomplete: React.ForwardRefExoticComponent<Pick<React.DetailedHTMLProps<React.InputHTMLAttributes<HTMLInputElement>, HTMLInputElement>, "key" | keyof React.InputHTMLAttributes<HTMLInputElement>> & {
    label?: React.ReactNode;
    type?: "number" | "text" | "search" | "tel" | "url" | "email" | "password" | undefined;
    error?: React.ReactNode;
    leftAddon?: React.ReactNode | {
        type: "button";
        label?: string | undefined; /**
         * 자동 완성 항목입니다.
         */
        icon?: React.ReactElement<any, string | React.JSXElementConstructor<any>> | undefined;
        onClick: () => void;
    };
    rightAddon?: React.ReactNode | {
        type: "button";
        label?: string | undefined; /**
         * 자동 완성 항목입니다.
         */
        icon?: React.ReactElement<any, string | React.JSXElementConstructor<any>> | undefined;
        onClick: () => void;
    };
    border?: "none" | "bottom" | "all" | undefined;
} & {
    /**
     * 자동 완성 항목입니다.
     */
    items: AutocompleteItem[];
    type?: "text" | "search" | "url" | "email" | "password" | undefined;
} & React.RefAttributes<HTMLInputElement>>;
export {};
