function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/* eslint-disable react/prop-types */
import React, { useCallback, useEffect, useImperativeHandle, useRef, useState } from 'react';
import styled, { css, keyframes } from 'styled-components';
import { TextField } from '.';
import { cv } from '../../style';
const Div = styled.div`
    position: relative;
`;
const SPACE = '​';
const FadeInFromTop = keyframes`
    0% {
        transform: translateY(-4px);
        opacity: 0;
    }
    100% {
        transform: translateY(0px);
        opacity: 1;
    }
`;
const FadeInFromBottom = keyframes`
    0% {
        transform: translateY(4px);
        opacity: 0;
    }
    100% {
        transform: translateY(0px);
        opacity: 1;
    }
`;
const OverlayDiv = styled.div`
    position: absolute;
    min-width: 230px;
    ${props => props.top !== undefined && `top: ${props.top + props.paddingHeight}px;`};
    ${props => props.right !== undefined && `right: ${props.right}px;`};
    ${props => props.bottom !== undefined && `bottom: ${props.bottom + props.paddingHeight}px;`};
    ${props => props.left !== undefined && `left: ${props.left}px;`};
    padding: 8px 0px;
    box-shadow: 0 8px 30px rgba(0, 0, 0, 10%);
    background-color: ${cv.bg_element1};
    font-size: 14px;
    display: flex;
    flex-direction: column;
    gap: 0px;
    z-index: 10;
    border-radius: 6px;
    border: solid 1px ${cv.border3};
    animation: ${props => props.top !== undefined ? FadeInFromTop : FadeInFromBottom} 150ms
        cubic-bezier(0.07, 0.75, 0.54, 0.93);
`;
const OverlayItem = styled.div`
    display: flex;
    align-items: center;
    justify-content: space-between;
    padding: 4px 16px;
    border-radius: 4px;
    background-color: ${cv.bg_element1};
    cursor: pointer;
    transition: 100ms;
    user-select: none;
    color: ${cv.text2};
    font-size: 0.875rem;
    line-height: 24px;

    ${props => props.isHover && css`
            color: ${cv.text1};
            background-color: ${cv.bg_element3};
        `}

    &:hover {
        color: ${cv.text1};
        background-color: ${cv.bg_element3};
    }
`;

function Item({
  id,
  onClick,
  isHover,
  onMouseOver,
  text
}) {
  return /*#__PURE__*/React.createElement(OverlayItem, {
    key: id,
    onClick: () => onClick(),
    isHover: isHover || false,
    onMouseOver: () => onMouseOver()
  }, text);
} // TODO: issue/21

/**
 * 자동 완성을 지원하는 \<TextField\>입니다.
 * 현재 영어만 사용할 수 있습니다. IME를 사용하는 언어(한국어 등)은 정상적으로 작동하지 않습니다.
 */


export const Autocomplete = /*#__PURE__*/React.forwardRef((props, ref) => {
  const inputRef = useRef(null);
  useImperativeHandle(ref, () => inputRef.current);
  const [currentItems, setCurrentItems] = useState(props.items);
  const [value, setValue] = useState(String(props.value || ''));
  const currentValue = useRef(String(props.value || ''));
  const [autocompleteSuggestion, setAutocompleteSuggestion] = useState('');
  const [isHighlight, setHighlight] = useState(false);
  const [isOpen, setIsOpen] = useState(false);
  const [cursor, setCursor] = useState(props.items[0].id);
  const [direction, setDirection] = useState({});
  const outRef = useRef(null);
  const overlayRef = useRef(null);
  useEffect(() => {
    function handleClickOutside(e) {
      if (outRef.current && !outRef.current.contains(e.target)) {
        setIsOpen(false);
      }
    }

    document.addEventListener('mousedown', handleClickOutside);
    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
    };
  }, [ref]);
  const calcPos = useCallback(() => {
    if (!outRef.current) return;
    const pos = {};

    if (outRef.current.getBoundingClientRect().right + 250 > (window.innerWidth >= 1200 ? (window.innerWidth - 1200) / 2 + 1200 : window.innerWidth)) {
      pos.right = 0;
    } else {
      pos.left = 0;
    }

    if (outRef.current.getBoundingClientRect().bottom + 300 > window.innerHeight) {
      pos.bottom = 0;
    } else {
      pos.top = 0;
    }

    setDirection(pos);
  }, []);
  const onInput = useCallback(e => {
    if (props.onInput) props.onInput(e);
  }, [props]);
  const onChange = useCallback(e => {
    setIsOpen(true);
    currentValue.current = e.target.value.replaceAll(SPACE, '');
    setValue(currentValue.current);
    const newCurrentItems = props.items.filter(item => item.text.startsWith(e.target.value));
    setCurrentItems(newCurrentItems);

    if (!props.items.find(ee => ee.id === cursor)?.text.startsWith(e.target.value)) {
      setCursor(newCurrentItems[0]?.id || -1);
    }

    if (newCurrentItems.length === 1 && currentValue.current === currentItems.find(ee => ee.id === cursor)?.text) {
      setHighlight(false);
    }

    setTimeout(() => {
      if (inputRef.current) {
        const event = new Event('change', {
          bubbles: true
        });

        if (props.onChange) {
          props.onChange({ ...event,
            nativeEvent: event,
            isDefaultPrevented: () => e.isDefaultPrevented(),
            isPropagationStopped: () => e.isPropagationStopped(),
            persist: () => e.persist(),
            target: inputRef.current,
            currentTarget: inputRef.current
          });
        }
      }
    }, 0);
  }, [currentItems, cursor, props]);
  const onFocus = useCallback(e => {
    if (props.onFocus) props.onFocus(e);
    calcPos();
    setIsOpen(true);
    const newCurrentItems = props.items.filter(item => item.text.startsWith(value));
    setCurrentItems(newCurrentItems);

    if (!props.items.find(ee => ee.id === cursor)?.text.startsWith(value)) {
      setCursor(newCurrentItems[0]?.id || -1);
    }
  }, [calcPos, cursor, props, value]);
  const onKeyDown = useCallback(e => {
    if (e.code === 'ArrowUp') {
      setCursor(prev => {
        const index = currentItems.findIndex(ee => ee.id === prev);

        if (currentItems[index - 1]) {
          return currentItems[index - 1].id;
        }

        return currentItems[currentItems.length - 1].id;
      });
      e.preventDefault();
    } else if (e.code === 'ArrowDown') {
      setCursor(prev => {
        const index = currentItems.findIndex(ee => ee.id === prev);

        if (currentItems[index + 1]) {
          return currentItems[index + 1].id;
        }

        return currentItems[0].id;
      });
      e.preventDefault();
    } else if (e.code === 'Tab') {
      setCursor(prev => {
        const index = currentItems.findIndex(ee => ee.id === prev);

        if (currentItems[index + 1]) {
          return currentItems[index + 1].id;
        }

        return currentItems[0].id;
      });
      e.preventDefault();
    } else if (e.code === 'Enter') {
      const text = currentItems.find(ee => ee.id === cursor)?.text;

      if (text) {
        setValue(text);
        setIsOpen(false);
        currentValue.current = text;
        setHighlight(false);
        inputRef.current?.blur();
        setTimeout(() => {
          const event = new Event('change', {
            bubbles: true
          });

          if (props.onChange) {
            props.onChange({ ...event,
              nativeEvent: event,
              isDefaultPrevented: () => false,
              isPropagationStopped: () => false,
              persist: () => null,
              target: inputRef.current,
              currentTarget: inputRef.current
            });
          }
        }, 0);
      }
    } else if (e.code === 'Escape') {
      setValue('');
      currentValue.current = '';
      setTimeout(() => {
        const event = new Event('change', {
          bubbles: true
        });

        if (props.onChange) {
          props.onChange({ ...event,
            nativeEvent: event,
            isDefaultPrevented: () => false,
            isPropagationStopped: () => false,
            persist: () => null,
            target: inputRef.current,
            currentTarget: inputRef.current
          });
        }
      }, 0);
      inputRef.current?.blur();
      setIsOpen(false);
    }

    if (e.code === 'Backspace') {
      if (window.getSelection()?.toString() === autocompleteSuggestion?.slice(currentValue.current.length, autocompleteSuggestion?.length)) {
        if (isHighlight) {
          setValue(`${currentValue.current} `);
        }
      }

      setHighlight(false);
    } else {
      setHighlight(true);
    }

    if (autocompleteSuggestion && currentValue.current.length < autocompleteSuggestion?.length) {
      setAutocompleteSuggestion(prev => (prev?.replaceAll(SPACE, '') || '') + SPACE);
    }

    if (props.onKeyDown) props.onKeyDown(e);
  }, [autocompleteSuggestion, currentItems, cursor, isHighlight, props]);
  const onKeyPress = useCallback(e => {
    if (props.onKeyPress) props.onKeyPress(e);

    if (autocompleteSuggestion && inputRef.current) {
      if (currentValue.current.length + 1 === autocompleteSuggestion.length) {
        setValue(currentValue.current);
        currentValue.current = autocompleteSuggestion;
      }
    }
  }, [autocompleteSuggestion, props]);
  const onKeyUp = useCallback(e => {
    setValue(currentValue.current);
    if (props.onKeyUp) props.onKeyUp(e);
  }, [props]);

  const onItemClick = id => {
    const itemValue = currentItems.find(e => e.id === id)?.text || '';
    currentValue.current = itemValue;
    setValue(itemValue);
    const newCurrentItems = props.items.filter(item => item.text.startsWith(itemValue));
    setCurrentItems(newCurrentItems);
    setCursor(id);
    setHighlight(false);
    setAutocompleteSuggestion(itemValue);

    if (inputRef.current) {
      inputRef.current.setAttribute('value', itemValue);
      inputRef.current.dispatchEvent(new Event('change', {
        bubbles: true
      }));
      setTimeout(() => {
        const event = new Event('change', {
          bubbles: true
        });

        if (props.onChange) {
          props.onChange({ ...event,
            nativeEvent: event,
            isDefaultPrevented: () => false,
            isPropagationStopped: () => false,
            persist: () => null,
            target: inputRef.current,
            currentTarget: inputRef.current
          });
        }
      }, 0);
    }

    setIsOpen(false);
  };

  useEffect(() => {
    setAutocompleteSuggestion(currentItems.find(e => e.id === cursor)?.text || null);
  }, [currentItems, cursor]);
  useEffect(() => {
    if (!inputRef.current) return;

    if (isHighlight && autocompleteSuggestion && value) {
      if (autocompleteSuggestion.includes(value)) {
        inputRef.current.setSelectionRange(currentValue.current.length, autocompleteSuggestion.length);
      }
    }
  }, [autocompleteSuggestion, isHighlight, value]);
  return /*#__PURE__*/React.createElement(Div, {
    ref: outRef
  }, /*#__PURE__*/React.createElement(TextField, _extends({}, props, {
    ref: inputRef,
    onInput: e => onInput(e),
    onChange: e => onChange(e),
    onKeyDown: e => onKeyDown(e),
    onKeyUp: e => onKeyUp(e),
    onKeyPress: e => onKeyPress(e),
    onFocus: e => onFocus(e) // eslint-disable-next-line no-nested-ternary
    ,
    value: value.length === 0 ? value : isHighlight ? autocompleteSuggestion || value : value
  })), isOpen && currentItems.length !== 0 && /*#__PURE__*/React.createElement(OverlayDiv, _extends({}, direction, {
    ref: overlayRef,
    paddingHeight: 40
  }), currentItems.map(e => /*#__PURE__*/React.createElement(Item, {
    key: e.id,
    id: e.id,
    text: e.text,
    onClick: () => onItemClick(e.id),
    isHover: e.id === cursor,
    onMouseOver: () => setCursor(e.id)
  }))));
});