/* eslint-disable react/destructuring-assignment */
import { X } from 'phosphor-react';
import React, { useEffect, useRef, useState } from 'react';
import styled, { keyframes } from 'styled-components';
import { cv } from '../../style';
const Divver = styled.div``;
const FadeInFromBottom = keyframes`
    0% {
        transform: translateY(10px);
        opacity: 0;
    }
    100% {
        transform: translateY(0px);
        opacity: 1;
    }
`;
const Background = styled.div`
    position: fixed;
    top: 0;
    left: 0;
    width: 100vw;
    height: calc(${cv.vh}*100);
    z-index: 99998;
    background-color: ${cv.black};
    transition: 200ms;
    opacity: ${props => props.isOpen ? 0.2 : 0};
`;
const ModalBoxDivver = styled.div`
    position: fixed;
    top: 0;
    left: 0;
    width: 100vw;
    height: calc(${cv.vh}*100);
    z-index: 99999;
    display: flex;
    align-items: center;
    justify-content: center;
    pointer-events: none;

    animation: ${FadeInFromBottom} 200ms cubic-bezier(0.07, 0.75, 0.54, 0.93);
`;
const ModalBox = styled.div`
    background-color: ${cv.bg_page2};
    color: ${cv.text1};
    box-shadow: 0px 4px 4px rgba(0, 0, 0, 0.1);
    border-radius: 8px;
    pointer-events: auto;
    width: ${props => props.width}px;
    max-width: 80vw;
    padding: ${props => props.isPadding ? 16 : 0}px;

    transition: 200ms;
    opacity: ${props => props.isOpen ? 1 : 0};
`;
const ModalTitle = styled.div`
    font-weight: 700;
    font-size: 20px;
`;
const ModalTitleBox = styled.div`
    display: flex;
    align-items: center;
    justify-content: space-between;
    margin-bottom: 8px;
    color: ${cv.text1};
`;
const CloseBtn = styled.div`
    cursor: pointer;
    padding: 6px;
    background-color: ${cv.bg_element1};
    transition: 200ms;
    display: flex;
    align-items: center;
    justify-content: center;
    border-radius: 25565px;

    &:hover {
        background-color: ${cv.bg_element2};
    }
`;
export function Modal(props) {
  const timer = useRef();
  const [isOpen, setOpen] = useState(props.isOpen);
  useEffect(() => {
    clearTimeout(timer.current);

    if (props.isOpen) {
      setOpen(props.isOpen);
    } else {
      timer.current = setTimeout(() => {
        setOpen(props.isOpen);
      }, 200);
    }
  }, [props.isOpen]);

  if (isOpen) {
    return /*#__PURE__*/React.createElement(Divver, null, /*#__PURE__*/React.createElement(Background, {
      isOpen: props.isOpen,
      onClick: () => props.setOpen(false)
    }), /*#__PURE__*/React.createElement(ModalBoxDivver, null, /*#__PURE__*/React.createElement(ModalBox, {
      isOpen: props.isOpen,
      width: props.width,
      isPadding: props.isPadding
    }, props.title && /*#__PURE__*/React.createElement(ModalTitleBox, null, /*#__PURE__*/React.createElement(ModalTitle, null, props.title), /*#__PURE__*/React.createElement(CloseBtn, {
      onClick: () => props.close()
    }, /*#__PURE__*/React.createElement(X, null))), props.content)));
  }

  return null;
}